==> vtigercrm7.1.0rc.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Settings/ExtensionStore.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is: vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'LBL_PUBLISHER'                => 'Editore'                     , 
	'LBL_LICENSE'                  => 'Licenza'                     , 
	'LBL_PUBLISHED_ON'             => 'Pubblicato su'               , 
	'LBL_INSTALL'                  => 'Installare'                  , 
	'LBL_UPGRADE'                  => 'Aggiornamento'               , 
	'LBL_VERSION'                  => 'Versione'                    , 
	'LBL_DECLINE'                  => 'Declino'                     , 
	'LBL_ACCEPT_AND_INSTALL'       => 'Accettare e installare'      , 
	'LBL_OK'                       => 'Ok'                          , 
	'LBL_EXTENSION_NOT_COMPATABLE' => 'Estensione non è compatibile', 
	'LBL_INVALID_FILE'             => 'File non valido'             , 
	'LBL_NO_LICENSE_PROVIDED'      => 'Nessuna licenza fornita'     , 
	'LBL_INSTALLATION'             => 'Installazione'               , 
	'LBL_FAILED'                   => 'Non riuscita'                , 
	'LBL_SUCCESSFULL'              => 'Successo'                    , 
	'LBL_INSTALLATION_LOG'         => 'Registro di installazione'   , 
	'LBL_UPDATED_MODULE'           => ' modulo è stato aggiornato con successo.', 
	'LBL_UPDATING_MODULE'          => 'Modulo di aggiornamento'     , 
	'LBL_VTIGER_EXTENSION_STORE'   => 'Vtiger Extension Store'      , 
	'LBL_SEARCH_FOR_AN_EXTENSION'  => 'Ricercare un\'estensione...' , 
	'LBL_DOWNLOADS'                => 'Download'                    , 
	'LBL_NO_EXTENSIONS_FOUND'      => 'Senza estensioni trovate'    , 
	'LBL_REGISTER_TO_MARKET_PLACE' => 'Registrati al Marketplace'   , 
	'LBL_MARKETPLACE_REGISTRATION' => 'Registrazione Marketplace'   , 
	'LBL_MARKETPLACE_LOGIN'        => 'Mercato Login'               , 
	'LBL_NEW_TO_MARKETPLCAE'       => 'Nuovo mercato?'              , 
	'LBL_CREATE_AN_ACCOUNT'        => 'Creare un nuovo account'     , 
	'LBL_SETUP_CARD_DETAILS'       => 'Installazione scheda dettagli', 
	'LBL_SETUP_CARD'               => 'Scheda di configurazione'    , 
	'LBL_CARD_NUMBER'              => 'Numero di carta'             , 
	'LBL_EXP_MONTH'                => 'Mese di exp'                 , 
	'LBL_EXP_YEAR'                 => 'Exp anno'                    , 
	'LBL_CVC_CODE'                 => 'Codice CVC'                  , 
	'LBL_RESET'                    => 'Reset'                       , 
	'LBL_EXTENSION_STORE'          => 'Extension Store'             , 
	'LBL_INSTALLED'                => 'Installato'                  , 
	'LBL_UPDATE_CARD_DETAILS'      => 'Aggiornamento scheda dettagli', 
	'LBL_BY'                       => 'di'                          , 
	'LBL_RATINGS'                  => 'Recensioni'                  , 
	'LBL_DESCRIPTION'              => 'Descrizione'                 , 
	'LBL_AUTHOR_INFORMATION'       => 'Informazioni sull\'autore'   , 
	'LBL_AUTHOR_NAME'              => 'Nome dell\'autore'           , 
	'LBL_PHONE'                    => 'Telefono'                    , 
	'LBL_EMAIL'                    => 'Posta elettronica'           , 
	'LBL_SCREEN_SHOTS'             => 'Screenshots'                 , 
	'LBL_CUSTOMER_RATINGS'         => 'Valutazioni cliente'         , 
	'LBL_CUSTOMER_REVIEWS'         => 'Commenti dei clienti'        , 
	'LBL_WRITE_A_REVIEW'           => 'Scrivi una recensione'       , 
	'LBL_CUSTOMER_REVIEW'          => 'Revisione del cliente'       , 
	'LBL_REVIEW'                   => 'Recensione'                  , 
	'LBL_CUSTOMERS_REVIEWED'       => 'Clienti recensiti'           , 
	'LBL_SINGLE_CUSTOMER_REVIEWED' => 'Singolo cliente recensito'   , 
	'LBL_INSTALLATION_FAILED'      => 'Installazione non riuscita'  , 
	'LBL_SUCCESSFULL_INSTALLATION' => 'Installazione riuscita'      , 
	'LBL_INSTALL_FROM_ZIP'         => 'Installare da Zip'           , 
	'LBL_MORE_DETAILS'             => 'Più dettagli'               , 
	'Install'                      => 'Installare'                  , 
	'Upgrade'                      => 'Aggiornamento'               , 
	'LBL_RATE_IT'                  => 'Votarla.'                    , 
	'LBL_UNINSTALL'                => 'Disinstallare'               , 
	'LBL_LAUNCH'                   => 'Lancio'                      , 
	'LBL_SIGN_UP_FOR_FREE'         => 'Iscriversi gratuitamente'    , 
	'LBL_EMAIL_ADDRESS'            => 'Indirizzo email'             , 
	'LBL_FIRST_NAME'               => 'Nome'                        , 
	'LBL_LAST_NAME'                => 'Cognome'                     , 
	'LBL_COMPANY_NAME'             => 'Nome Comapany'               , 
	'LBL_PASSWORD'                 => 'Password'                    , 
	'LBL_CONFIRM_PASSWORD'         => 'Conferma password'           , 
	'LBL_REGISTER'                 => 'Registro'                    , 
	'LBL_EXTENSION_STORE_LOGIN'    => 'Extensionstore Login'        , 
	'LBL_REMEMBER_ME'              => 'Ricordati di me'             , 
	'LBL_TRY_IT'                   => 'Provalo'                     , 
	'LBL_TRIAL_INSTALLED'          => 'Prova installato'            , 
	'LBL_BUY'                      => 'Acquista '                   , 
	'LBL_LOGIN_TO_MARKET_PLACE'    => 'Accedere al Marketplace'     , 
	'LBL_LOGIN'                    => 'Login'                       , 
	'LBL_PHP_EXTENSION_LOADER_IS_NOT_AVAIABLE' => 'Si prega di installare il caricatore di estensione', 
	'LBL_INSTALL_EXTENSION_LOADER' => 'Installare l\'estensione Loader', 
	'LBL_TO_CONTINUE_USING_EXTENSION_STORE' => 'To continue using Extension Store please install ', 
	'LBL_DOWNLOAD'                 => 'Scarica'                     , 
	'LBL_COMPATIABLE_EXTENSION'    => ' e attivarla come zend_extension.', 
	'LBL_MORE_DETAILS_ON_INSTALLATION' => 'Per maggiori dettagli sull\'installazione ', 
	'LBL_READ_HERE'                => 'Leggi qui'                   , 
	'LBL_REVIEWS'                  => 'Recensioni'                  , 
	'LBL_SIGNUP_FOR_MARKET_PLACE'  => 'Signup for Marketplace'      , 
	'LBL_UNAUTHORIZED'             => 'Non autorizzato'             , 
	'LBL_EXPIRY_DATE'              => 'Data di scadenza'            , 
	'firstname'                    => 'Nome'                        , 
	'lastname'                     => 'Cognome'                     , 
	'email'                        => 'Posta elettronica'           , 
	'company'                      => 'Azienda'                     , 
	'Phone'                        => 'Telefono'                    , 
	'Website'                      => 'Sito Web'                    , 
	'LBL_SECURITY_CODE'            => 'Codice di sicurezza'         , 
	'LBL_WHAT_IS_SECURITY_CODE'    => 'Qual è il codice di sicurezza?', 
	'LBL_CARD_NUMBER_PLACEHOLDER'  => 'numero di 16 cifre sulla carta', 
	'LBL_SECURITY_CODE_HELP_CONTENT' => 'Il CVV Number(Card Verification Value) sulla vostra carta di credito è un numero a 3 cifre su VISA ®, MasterCard ® ecc... carte di credito di marca.',
    'LBL_MARKET_PLACE' => 'mercato',
);
$jsLanguageStrings = array(
	'JS_PLEASE_SETUP_CARD_DETAILS_TO_INSTALL_THIS_EXTENSION' => 'Prego impostare i dettagli della carta di installare questa estensione', 
	'JS_UPDATE_CARD_DETAILS'       => 'Aggiornamento scheda dettagli', 
	'JS_ON'                        => 'on'                          , 
	'JS_RATINGS'                   => 'Ratings'                     , 
	'JS_INSTALLED'                 => 'Installato'                  , 
	'JS_TRIAL_INSTALLED'           => 'Trial Installed'             , 
	'JS_PLEASE_INSTALL_EXTENSION_LOADER_TO_INSTALL_THIS_EXTENSION_FROM_BELOW_LINK' => 'Si prega di installare loader prolunga per installare questa estensione dal basso di collegamento', 
	'JS_PLEASE_LOGIN_TO_MARKETPLACE_FOR_INSTALLING_EXTENSION' => 'Effettua il login al marketplace per l\'installazione di estensione', 
	'JS_PLEASE_SETUP_CARD_DETAILS_TO_INSTALL_EXTENSION' => 'Please setup card details to install extension', 
	'JS_PLEASE_LOGIN_TO_MARKETPLACE_FOR_UNINSTALLING_EXTENSION' => 'Effettua il login al marketplace per la disinstallazione di estensione', 
	'JS_CARD_DETAILS_UPDATED'      => 'Card details updated!'       , 
	'JS_PASSWORDS_MISMATCH'        => 'Le password non corrispondono!', 
);

==> vtigercrm7.5.0.tar.gz: vtigercrm/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Settings/ExtensionStore.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is: vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'LBL_PUBLISHER'                => 'Editore'                     , 
	'LBL_LICENSE'                  => 'Licenza'                     , 
	'LBL_PUBLISHED_ON'             => 'Pubblicato su'               , 
	'LBL_INSTALL'                  => 'Installare'                  , 
	'LBL_UPGRADE'                  => 'Aggiornamento'               , 
	'LBL_VERSION'                  => 'Versione'                    , 
	'LBL_DECLINE'                  => 'Declino'                     , 
	'LBL_ACCEPT_AND_INSTALL'       => 'Accettare e installare'      , 
	'LBL_OK'                       => 'Ok'                          , 
	'LBL_EXTENSION_NOT_COMPATABLE' => 'Estensione non è compatibile', 
	'LBL_INVALID_FILE'             => 'File non valido'             , 
	'LBL_NO_LICENSE_PROVIDED'      => 'Nessuna licenza fornita'     , 
	'LBL_INSTALLATION'             => 'Installazione'               , 
	'LBL_FAILED'                   => 'Non riuscita'                , 
	'LBL_SUCCESSFULL'              => 'Successo'                    , 
	'LBL_INSTALLATION_LOG'         => 'Registro di installazione'   , 
	'LBL_UPDATED_MODULE'           => ' modulo è stato aggiornato con successo.', 
	'LBL_UPDATING_MODULE'          => 'Modulo di aggiornamento'     , 
	'LBL_VTIGER_EXTENSION_STORE'   => 'Negozio estensioni Vtiger'      , 
	'LBL_SEARCH_FOR_AN_EXTENSION'  => 'Ricercare un\'estensione...' , 
	'LBL_DOWNLOADS'                => 'Download'                    , 
	'LBL_NO_EXTENSIONS_FOUND'      => 'Nessuna estensione trovata'    , 
	'LBL_REGISTER_TO_MARKET_PLACE' => 'Registrati al Marketplace'   , 
	'LBL_MARKETPLACE_REGISTRATION' => 'Registrazione Marketplace'   , 
	'LBL_MARKETPLACE_LOGIN'        => 'Login Marketplace'               , 
	'LBL_NEW_TO_MARKETPLCAE'       => 'Sei Nuovo del Marketplace?'              , 
	'LBL_CREATE_AN_ACCOUNT'        => 'Creare un nuovo account'     , 
	'LBL_SETUP_CARD_DETAILS'       => 'Installazione scheda dettagli', 
	'LBL_SETUP_CARD'               => 'Scheda di configurazione'    , 
	'LBL_CARD_NUMBER'              => 'Numero di carta'             , 
	'LBL_EXP_MONTH'                => 'Mese di scad.'                 , 
	'LBL_EXP_YEAR'                 => 'Anno di scad.'                    , 
	'LBL_CVC_CODE'                 => 'Codice CVC'                  , 
	'LBL_RESET'                    => 'Reset'                       , 
	'LBL_EXTENSION_STORE'          => 'Negozio estensioni'             , 
	'LBL_INSTALLED'                => 'Installato'                  , 
	'LBL_UPDATE_CARD_DETAILS'      => 'Aggiornamento scheda dettagli', 
	'LBL_BY'                       => 'di'                          , 
	'LBL_RATINGS'                  => 'Recensioni'                  , 
	'LBL_DESCRIPTION'              => 'Descrizione'                 , 
	'LBL_AUTHOR_INFORMATION'       => 'Informazioni sull\'autore'   , 
	'LBL_AUTHOR_NAME'              => 'Nome dell\'autore'           , 
	'LBL_PHONE'                    => 'Telefono'                    , 
	'LBL_EMAIL'                    => 'Posta elettronica'           , 
	'LBL_SCREEN_SHOTS'             => 'Screenshots'                 , 
	'LBL_CUSTOMER_RATINGS'         => 'Valutazioni cliente'         , 
	'LBL_CUSTOMER_REVIEWS'         => 'Commenti dei clienti'        , 
	'LBL_WRITE_A_REVIEW'           => 'Scrivi una recensione'       , 
	'LBL_CUSTOMER_REVIEW'          => 'Revisione del cliente'       , 
	'LBL_REVIEW'                   => 'Recensione'                  , 
	'LBL_CUSTOMERS_REVIEWED'       => 'Clienti recensiti'           , 
	'LBL_SINGLE_CUSTOMER_REVIEWED' => 'Singolo cliente recensito'   , 
	'LBL_INSTALLATION_FAILED'      => 'Installazione non riuscita'  , 
	'LBL_SUCCESSFULL_INSTALLATION' => 'Installazione riuscita'      , 
	'LBL_INSTALL_FROM_ZIP'         => 'Installare da Zip'           , 
	'LBL_MORE_DETAILS'             => 'Più dettagli'               , 
	'Install'                      => 'Installare'                  , 
	'Upgrade'                      => 'Aggiornamento'               , 
	'LBL_RATE_IT'                  => 'Votarla.'                    , 
	'LBL_UNINSTALL'                => 'Disinstallare'               , 
	'LBL_LAUNCH'                   => 'Lancio'                      , 
	'LBL_SIGN_UP_FOR_FREE'         => 'Iscriversi gratuitamente'    , 
	'LBL_EMAIL_ADDRESS'            => 'Indirizzo email'             , 
	'LBL_FIRST_NAME'               => 'Nome'                        , 
	'LBL_LAST_NAME'                => 'Cognome'                     , 
	'LBL_COMPANY_NAME'             => 'Nome Azienda'               , 
	'LBL_PASSWORD'                 => 'Password'                    , 
	'LBL_CONFIRM_PASSWORD'         => 'Conferma password'           , 
	'LBL_REGISTER'                 => 'Registro'                    , 
	'LBL_EXTENSION_STORE_LOGIN'    => 'Logine negozio estensioni'        , 
	'LBL_REMEMBER_ME'              => 'Ricordati di me'             , 
	'LBL_TRY_IT'                   => 'Provalo'                     , 
	'LBL_TRIAL_INSTALLED'          => 'Prova installata'            , 
	'LBL_BUY'                      => 'Acquista '                   , 
	'LBL_LOGIN_TO_MARKET_PLACE'    => 'Accedere al Marketplace'     , 
	'LBL_LOGIN'                    => 'Login'                       , 
	'LBL_PHP_EXTENSION_LOADER_IS_NOT_AVAIABLE' => 'Si prega di installare il caricatore di estensione PHP', 
	'LBL_INSTALL_EXTENSION_LOADER' => 'Installare l\'estensione Loader', 
	'LBL_TO_CONTINUE_USING_EXTENSION_STORE' => 'To continue using Extension Store please install ', 
	'LBL_DOWNLOAD'                 => 'Scarica'                     , 
	'LBL_COMPATIABLE_EXTENSION'    => ' e attivarla come zend_extension.', 
	'LBL_MORE_DETAILS_ON_INSTALLATION' => 'Per maggiori dettagli sull\'installazione ', 
	'LBL_READ_HERE'                => 'Leggi qui'                   , 
	'LBL_REVIEWS'                  => 'Recensioni'                  , 
	'LBL_SIGNUP_FOR_MARKET_PLACE'  => 'Signup for Marketplace'      , 
	'LBL_UNAUTHORIZED'             => 'Non autorizzato'             , 
	'LBL_EXPIRY_DATE'              => 'Data di scadenza'            , 
	'firstname'                    => 'Nome'                        , 
	'lastname'                     => 'Cognome'                     , 
	'email'                        => 'Posta elettronica'           , 
	'company'                      => 'Azienda'                     , 
	'Phone'                        => 'Telefono'                    , 
	'Website'                      => 'Sito Web'                    , 
	'LBL_SECURITY_CODE'            => 'Codice di sicurezza'         , 
	'LBL_WHAT_IS_SECURITY_CODE'    => 'Qual è il codice di sicurezza?', 
	'LBL_CARD_NUMBER_PLACEHOLDER'  => 'numero di 16 cifre sulla carta', 
	'LBL_SECURITY_CODE_HELP_CONTENT' => 'Il CVV Number(Card Verification Value) sulla vostra carta di credito è un numero a 3 cifre su VISA ®, MasterCard ® ecc... carte di credito di marca.',
    'LBL_MARKET_PLACE' => 'mercato',
);
$jsLanguageStrings = array(
	'JS_PLEASE_SETUP_CARD_DETAILS_TO_INSTALL_THIS_EXTENSION' => 'Prego impostare i dettagli della carta di installare questa estensione', 
	'JS_UPDATE_CARD_DETAILS'       => 'Aggiornamento scheda dettagli', 
	'JS_ON'                        => 'il'                          , 
	'JS_RATINGS'                   => 'Valutazioni'                     , 
	'JS_INSTALLED'                 => 'Installato'                  , 
	'JS_TRIAL_INSTALLED'           => 'Prova installata'             , 
	'JS_PLEASE_INSTALL_EXTENSION_LOADER_TO_INSTALL_THIS_EXTENSION_FROM_BELOW_LINK' => 'Si prega di installare questa estensione dal collegamento qui di sotto', 
	'JS_PLEASE_LOGIN_TO_MARKETPLACE_FOR_INSTALLING_EXTENSION' => 'Effettua il login al marketplace per l\'installazione di estensione', 
	'JS_PLEASE_SETUP_CARD_DETAILS_TO_INSTALL_EXTENSION' => 'Inserire i detagli della carta per installa l\'estensione', 
	'JS_PLEASE_LOGIN_TO_MARKETPLACE_FOR_UNINSTALLING_EXTENSION' => 'Effettua il login al marketplace per la disinstallazione dell\'estensione', 
	'JS_CARD_DETAILS_UPDATED'      => 'Dettagli carta aggiornati!'       , 
	'JS_PASSWORDS_MISMATCH'        => 'Le password non corrispondono!', 
);
